==> haskell-blaze-builder-0.4.0.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.2
id: blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
key: blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Compat.Write Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Internal.Write
    Blaze.ByteString.Builder.Word
abi: efe227a7a23c0583e6a2d74f96c7367f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-builder-0.4.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-builder-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/blaze-builder-0.4.0.2
hs-libraries: HSblaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
depends:
    base-4.10.1.0 deepseq-1.4.3.0 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-builder-0.4.0.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.2
id: blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
key: blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Compat.Write Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Internal.Write
    Blaze.ByteString.Builder.Word
abi: 3962b4cebc9bc66ccf8167322740d159
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-builder-0.4.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-builder-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/blaze-builder-0.4.0.2
hs-libraries: HSblaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
depends:
    base-4.10.1.0 deepseq-1.4.3.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
